from simplenlp.euro import StemmedEuroNL

class NL(StemmedEuroNL):
    def __init__(self):
        super(NL, self).__init__('fr')
